-----------------------------------
-- Setting up scope and libs
-----------------------------------

local AddonName = select(1, ...);
iLocation = LibStub("AceAddon-3.0"):NewAddon(AddonName, "AceEvent-3.0");

local L = LibStub("AceLocale-3.0"):GetLocale(AddonName);

local LibQTip = LibStub("LibQTip-1.0");
local LibTourist = LibStub("LibTourist-3.0");

local _G = _G;

-----------------------------------------
-- Variables, functions and colors
-----------------------------------------

local Tooltip; -- our tooltip
local CoordsTimers;

local CurrentZone = "";
local CurrentPosX = 0;
local CurrentPosY = 0;

local COLOR_GOLD = "|cfffed100";

local function tclear(t, wipe)
	if( type(t) ~= "table" ) then return end;
	for k in pairs(t) do
		t[k] = nil;
	end
	t[''] = 1;
	t[''] = nil;
	if( wipe ) then
		t = nil;
	end
end

-----------------------------
-- Setting up the feed
-----------------------------

iLocation.Feed = LibStub("LibDataBroker-1.1"):NewDataObject(AddonName, {
	type = "data source",
	text = "iLocation",
	icon = "Interface\\Addons\\iLocation\\Images\\iGuild",
});

iLocation.Feed.OnEnter = function(anchor)
	for k, v in LibQTip:IterateTooltips() do
		if( type(k) == "string" and strsub(k, 1, 6) == "iSuite" ) then
			v:Release(k);
		end
	end
		
	Tooltip = LibQTip:Acquire("iSuite"..AddonName);
	Tooltip:SetAutoHideDelay(0.1, anchor);
	Tooltip:SmartAnchorTo(anchor);
	iLocation:UpdateTooltip();
	Tooltip:Show();
end

----------------------
-- OnInitialize
----------------------

function iLocation:OnInitialize()
	CoordsTimer = LibStub("AceTimer-3.0"):ScheduleRepeatingTimer(self.UpdateCoords, 1);
	
	self:RegisterEvent("PLAYER_ENTERING_WORLD", "UpdateZone");
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA", "UpdateZone");
	
	
end

-----------------------
-- Event Handling
-----------------------

function iLocation:UpdateZone()
	CurrentZone = _G.GetRealZoneText() or _G.UNKNOWN;
	
	self:UpdateFeed();
end

function iLocation:UpdateCoords()
	CurrentPosX, CurrentPosY = _G.GetPlayerMapPosition("player");
	
	iLocation:UpdateFeed();
end

-----------------------
-- Update Feed
-----------------------

function iLocation:UpdateFeed()
	local r, g, b = LibTourist:GetFactionColor(CurrentZone);
	self.Feed.text = ("|cff%02x%02x%02x%s|r"):format(r *255, g *255, b *255, CurrentZone);
	
	self.Feed.text = self.Feed.text.." "..("%.0f,%.0f"):format(CurrentPosX *100, CurrentPosY *100);
end

-----------------------
-- UpdateTooltip
-----------------------

function iLocation:UpdateTooltip()
	Tooltip:Clear();
	Tooltip:SetColumnLayout(1, "CENTER");
	Tooltip:AddHeader("Nothing here atm");
end